
History
=======

1.2
---

- adopt to yafowil 1.2
  [jensens, 2011-09-20]

- resource available in plain Zope2
  [jensens, 2011-09-20]

1.1
---

- adopt to yafowil 1.1
  [rnix, 2011-07-08]

1.0.1
-----

- test coverage
  [rnix, 2011-05-07]

1.0
---

- made it work
  [jensens, 2010-11-24]
